// items.js
let otherItems = [
    { name: "Item 3", img: "https://via.placeholder.com/50" },
    { name: "Item 4", img: "https://via.placeholder.com/50" },
    { name: "Item 5", img: "https://via.placeholder.com/50" }
];

// 🛠️ Crée un élément item avec drag & click (édition d'image)
function createItemElement(item) {
    const itemDiv = document.createElement("div");
    itemDiv.classList.add("item");
    itemDiv.setAttribute("draggable", "true");
    itemDiv.dataset.name = item.name;

    const img = document.createElement("img");
    img.src = item.img;
    img.alt = item.name;
    img.classList.add("item-img");

    itemDiv.appendChild(img);
    return itemDiv;
}

// 📦 Affiche les items non triés
function renderItems(itemsList) {
    itemsList.innerHTML = "";
    otherItems.forEach(item => {
        const itemDiv = createItemElement(item);
        itemsList.appendChild(itemDiv);
    });
}

// 🎨 Modification d'une image via upload
function editItem(itemName) {
    const input = document.createElement("input");
    input.type = "file";
    input.accept = "image/*";
    input.style.display = "none";

    input.addEventListener("change", function () {
        const file = input.files[0];
        if (file) {
            const reader = new FileReader();
            reader.onload = function (e) {
                updateItemImage(itemName, e.target.result);
            };
            reader.readAsDataURL(file);
        }
    });

    document.body.appendChild(input);
    input.click();
    document.body.removeChild(input);
}

// 🔄 Met à jour l'image d'un item
function updateItemImage(itemName, newImg) {
    let item = otherItems.find(i => i.name === itemName);

    if (!item) {
        initTiers.forEach(tier => {
            const foundItem = tier.items.find(i => i.name === itemName);
            if (foundItem) item = foundItem;
        });
    }

    if (item) {
        item.img = newImg;
        renderTiers();
        renderItems();
    }
}

// ➕ Ajout d'un nouvel item
function addItem(name, img, itemsList) {
    otherItems.push({ name, img });
    renderItems(itemsList);
}
