// tiers.js
const initTiers = [
    { name: 'S', color: '#FF8C42', items: [{ name: "Item 1", img: "https://picsum.photos/50" }] },
    { name: 'A', color: '#EFBF3E', items: [{ name: "Item 2", img: "https://via.placeholder.com/50" }] },
    { name: 'B', color: '#C2C236', items: [] },
    { name: 'C', color: '#6FBF73', items: [] },
    { name: 'D', color: '#4E9A51', items: [] }
];

// 🖼️ Fonction pour afficher les tiers avec leurs items
function renderTiers(container) {
    container.innerHTML = "";
    initTiers.forEach((tier, index) => {
        const tierDiv = document.createElement("div");
        tierDiv.classList.add("row", "align-items-center", "tier-row");
        tierDiv.dataset.index = index;
        tierDiv.dataset.tier = tier.name;
        tierDiv.innerHTML = `
            <div class="col-2 text-center p-2" style="background: ${tier.color}">
                <h3 class="tier-title">${tier.name}</h3>
            </div>
            <div class="col-7 tier-content d-flex flex-wrap gap-2 p-2"></div>
            <div class="col-3 actions text-center">
                <button class="btn move-up"><i class="fa fa-angle-up"></i></button>
                <button class="btn move-down"><i class="fa fa-angle-down"></i></button>
                <button class="btn delete-tier"><i class="fa fa-trash"></i></button>
            </div>
        `;
        const tierContent = tierDiv.querySelector(".tier-content");

        tier.items.forEach(item => {
            const itemDiv = createItemElement(item);
            tierContent.appendChild(itemDiv);
        });

        container.appendChild(tierDiv);
    });
}

// 🔄 Déplace un tier dans la liste
function moveTier(index, direction) {
    if (direction === "up" && index > 0) {
        [initTiers[index], initTiers[index - 1]] = [initTiers[index - 1], initTiers[index]];
    } else if (direction === "down" && index < initTiers.length - 1) {
        [initTiers[index], initTiers[index + 1]] = [initTiers[index + 1], initTiers[index]];
    }
    renderTiers();
}

// 🏷️ Édition du titre d'un tier
function editTitle(element, index) {
    let currentTitle = element.textContent;
    element.outerHTML = `<input type="text" class="input-title" value="${currentTitle}" data-index="${index}">`;
    document.querySelector(".input-title").focus();
}
